An L7 Rule is a single, simple logical test which returns either true or false.

Type: The L7 rule type. One of COOKIE, FILE_TYPE, HEADER, HOST_NAME, or PATH.

- COOKIE: The rule looks for a cookie named by the key parameter and compares it against the value parameter in the rule.
- HEADER: The rule looks for a header defined in the key parameter and compares it against the value parameter in the rule.
- FILE_TYPE: The rule compares the last portion of the URI against the value parameter in the rule. (eg. "txt", "jpg", etc.)
- PATH: The rule compares the path portion of the HTTP URI against the value parameter in the rule.
- HOST_NAME: The rule does a comparison between the HTTP/1.1 hostname in the request against the value parameter in the rule.

Compare Type: The comparison type for the L7 rule. One of CONTAINS, ENDS_WITH, EQUAL_TO, REGEX, or STARTS_WITH.

- REGEX: Perl type regular expression matching.
- STARTS_WITH: String starts with.
- ENDS_WITH: String ends with.
- CONTAINS: String contains.
- EQUAL_TO: String is equal to.

Key: The key to use for the comparison. For example, the name of the cookie to evaluate.

Value: The value to use for the comparison. For example, the file type to compare.

Invert: When true the logic of the rule is inverted. For example, with invert true, equal to would become not equal to.